@@ -1,5 +1,5 @@
 package Spreadsheet::Read::Ingester ;
-$Spreadsheet::Read::Ingester::VERSION = '0.004';
+$Spreadsheet::Read::Ingester::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -42,6 +42,10 @@ sub cleanup {
   my $s = shift;
   my $age = shift // 30;
 
+  if ($age eq '0') {
+    $age = -1;
+  }
+
   my $configdir = File::UserConfig->new(dist => 'Spreadsheet-Read-Ingester')->configdir;
 
   opendir (DIR, $configdir) or die 'Could not open directory.';
@@ -49,7 +53,10 @@ sub cleanup {
   closedir (DIR);
   foreach my $file (@files) {
     $file = File::Spec->catfile($configdir, $file);
-    unlink $file if -M $file >= $age;
+    next if (-d $file);
+    print STDERR -M $file;
+    print STDERR "\n";
+    unlink $file if -M "$file" >= $age;
   }
 }
 
@@ -79,7 +86,7 @@ Spreadsheet::Read::Ingester - ingest and save csv and spreadsheet data to a perl
 
 =head1 DESCRIPTION
 
-This module is intended to be a drop-in replacement for <Spreadsheet::Read> and
+This module is intended to be a drop-in replacement for L<Spreadsheet::Read> and
 is a simple, unobtrusive wrapper for it.
 
 Parsing spreadsheet and csv data files is time consuming, especially with large
